import { Line, Ray, RayRange } from '../../index';
/**
 * Calculates the point of intersection between a ray and a line.
 *
 * @param ray   The ray that intersects the line.
 * @param line  The line that intersects the ray.
 * @param range The extent of the ray. Specifies whether the ray is
 *              shooting both forward and backward, or only forward.
 *
 * @module  Intersection
 */
export declare function rayLine(ray: Ray, line: Line, range?: RayRange): {
    /** True if the ray and line intersect. */
    readonly intersects: boolean;
    /** The parameter along `ray` where the intersection occurs. Use [[Ray.pointAt]] to get the actual point. */
    readonly rayU: number;
    /** The parameter along `line` where the intersection occurs. Use [[Line.pointAt]] to get the actual point. */
    readonly lineU: number;
};
/**
 * Calculates the point of intersection between two rays.
 *
 * @param rayA      The first ray.
 * @param rayB      The second ray.
 * @param range     The extent of the ray. Specifies whether the ray is
 *                  shooting both forward and backward, or only forward.
 *
 * @module  Intersection
 */
export declare function rayRay(rayA: Ray, rayB: Ray, range?: RayRange): {
    /** True if the two rays intersect. */
    readonly intersects: boolean;
    /** The parameter along `rayA` where the intersection occurs. Use [[Ray.pointAt]] to get the actual point. */
    readonly rayAU: number;
    /** The parameter along `rayB` where the intersection occurs. Use [[Ray.pointAt]] to get the actual point. */
    readonly rayBU: number;
};
