import { BoundingBox, IntervalSorted, Line, Ray, RayRange } from '../../index';
/**
 * Calculates which portion of a line is inside a bounding box. Returns the parameter of the interval inside.
 * @param line      The line to intersect.
 * @param box       The bounding box that intersects the line.
 *
 * @module  Intersection
 */
export declare function lineBox(line: Line, box: BoundingBox): {
    /** True if the line intersects the box. */
    readonly intersects: boolean;
    /** The portion of the line within the box. Use [[Line.pointAt]] to get actual points. Note that the two ends of the interval aren't always points of intersection – for example, a line could be completely inside a box without touching the sides, in which case the interval would be the full length of the line (0 to 1) but neither 0 nor 1 would be a point of intersection. */
    readonly domain: IntervalSorted;
};
/**
 * Calculates which portion of a ray is inside a bounding box. Returns the parameters of the interval inside.
 * @param ray      The ray to intersects.
 * @param box      The bounding box that intersects the ray.
 * @param range    The extent of the ray. Specifies whether the ray is
 *                 shooting both forward and backward, or only forward.
 *
 * @module Intersection
 */
export declare function rayBox(ray: Ray, box: BoundingBox, range?: RayRange): {
    /** True if the ray intersects the box. */
    readonly intersects: boolean;
    /** The portion of the ray within the box. Use [[Ray.pointAt]] to get actual points. Note that if you've limited the ray's range to only shoot forward, one value in the interval could be the ray's start rather than the point of intersection. */
    readonly domain: IntervalSorted;
};
