import { Circle, Line, Ray, RayRange } from '../../index';
/**
 * The number of intersections between a line and a circle. This value is returned by [[Intersection.lineCircle]].
 */
export declare enum LineCircleIntersection {
    none = 0,
    single = 1,
    multiple = 2
}
/**
 * Calculates the points of intersection between a line and a circle.
 * @param line      The line to intersect.
 * @param circle    The circle that intersects the line.
 *
 * @module  Intersection
 */
export declare function lineCircle(line: Line, circle: Circle): {
    /** The number of times the line intersects the circle. */
    readonly intersects: LineCircleIntersection;
    /** The parameters along the line where the intersections occur. Use [[Line.pointAt]] to get the actual points. */
    readonly u: readonly number[];
};
/**
 * Calculates the points of intersection between a ray and a circle.
 * @param ray     The ray to intersect.
 * @param circle  The circle that intersects the ray.
 * @param range   The extent of the ray. Specifies whether the ray is
 *                 shooting both forward and backward, or only forward.
 *
 * @module Intersection
 */
export declare function rayCircle(ray: Ray, circle: Circle, range?: RayRange): {
    /** The number of times the ray intersects the circle. */
    readonly intersects: LineCircleIntersection;
    /** The parameters along the ray where the intersections occur. Use [[Ray.pointAt]] to get the actual points. */
    readonly u: readonly number[];
};
