import { Line, Point, Polyline } from '../../index';
/**
 * Returns the number of times a horizontal ray intersects with a polyline.
 *
 * This is a more efficient version of [[Intersection.ray]] used for [[polyline.contains]].
 * Assumes point has already been tested for inclusion within the polyline's bounding box.
 *
 *
 * @param start       The start of the ray. The ray will be shot with a vector of 1,0
 * @param polyline    The polyline to test for intersection
 * @returns           The number of times the ray intersects with the polyline
 *
 * @private
 */
export declare function horizontalRayPolyline(start: Point, polyline: Polyline): number;
/**
 * Calculates the intersection between a horizontal ray starting at [start] and intersecting with [line].
 *
 * This is more efficient than the LineLineInfinite algorithm because it can identify whether a line will intersect with
 * the ray prior to running the intersection calculation. This allows many lines to be discarded early.
 *
 * @param start: The start point for the ray, which will run in the [1,0] direction
 * @param line: The line to test the intersection with
 *
 * @private
 */
export declare function horizontalRayLine(start: Point, line: Line): boolean;
