import { BoundingBox, Circle, Line, Point, Polygon, Polyline, Ray, RayRange, Rectangle } from '../../index';
/**
 * Calculates where the line intersects other geometry and returns the parameters
 * for these points of intersection.
 *
 * This function can be accessed directly through [[Line.intersection]].
 *
 * @param theLine       The line to intersect.
 * @param otherGeom     The geometry that intersects the line.
 * @returns             The parameters along `theLine` where the intersections occur. Use [[Line.pointAt]] to get actual points.
 *
 * @module  Intersection
 */
export declare function line(theLine: Line, otherGeom: Point | Line | Ray | BoundingBox | Circle | Rectangle | Polyline | Polygon | ReadonlyArray<Point | Line | Ray | BoundingBox | Circle | Rectangle | Polyline | Polygon>): readonly number[];
/**
 * Calculates where the ray intersects other geometry and returns the parameters
 * for these points of intersection.
 *
 * This function can be accessed directly through [[Ray.intersection]].
 *
 * @param theRay        The ray to intersect.
 * @param otherGeom     The geometry that intersects the ray.
 * @param range         The extent of the ray. Specifies whether the ray is
 *                      shooting both forward and backward, or only forward.
 * @returns             The parameters along `theRay` where the intersections occur. Use [[Ray.pointAt]] to get actual points.
 *
 * @module  Intersection
 */
export declare function ray(theRay: Ray, otherGeom: Point | Line | Ray | BoundingBox | Circle | Rectangle | Polyline | Polygon | ReadonlyArray<Point | Line | Ray | BoundingBox | Circle | Rectangle | Polyline | Polygon>, range?: RayRange): readonly number[];
/**
 * Calculates where the polyline intersects other geometry and returns the parameters
 * for these points of intersection.
 *
 * This function can be accessed directly through [[Polyline.intersection]].
 *
 * @note Only accounts for crossings, not coincident overlaps.
 *
 * @param thePolyline   The polyline to intersect.
 * @param otherGeom     The geometry that intersects the polyline.
 * @returns             The parameters along `thePolyline` where the intersections occur. Use [[Polyline.pointAt]] to get actual points.
 *
 * @module  Intersection
 */
export declare function polyline(thePolyline: Polyline, otherGeom: Point | Line | Ray | BoundingBox | Circle | Rectangle | Polyline | Polygon | ReadonlyArray<Point | Line | Ray | BoundingBox | Circle | Rectangle | Polyline | Polygon>): readonly number[];
